as_edge

Function as_edge 

pub fn as_edge(v: &Value) -> Option<Edge>
Convert a driver Value into a typed Edge.

Returns None if v is not an edge object: it must be an object that has both start_node and end_node keys.