as_path

Function as_path 

pub fn as_path(v: &Value) -> Option<Path>
Convert a driver Value into a typed Path.

Returns None if v is not a path object: it must be an object that has both nodes and edges keys. Individual entries that fail to decode as a Node/Edge are skipped.