pub struct GrpcClient { /* private fields */ }Expand description
gRPC client for Geode.
Provides gRPC-based connection to the Geode database server using the tonic-generated service client.
Implementations
Sourceimpl GrpcClient
impl GrpcClient
Sourcepub async fn query(&mut self, gql: &str) -> Result<(Page, Option<String>)>
pub async fn query(&mut self, gql: &str) -> Result<(Page, Option<String>)>
Execute a GQL query.
Sourcepub async fn query_with_params(
&mut self,
gql: &str,
params: &HashMap<String, Value>,
) -> Result<(Page, Option<String>)>
pub async fn query_with_params( &mut self, gql: &str, params: &HashMap<String, Value>, ) -> Result<(Page, Option<String>)>
Execute a GQL query with parameters.
Sourcepub async fn savepoint(&mut self, _name: &str) -> Result<()>
pub async fn savepoint(&mut self, _name: &str) -> Result<()>
Create a savepoint within the current transaction.
Note: Savepoints are not yet supported via the gRPC service definition. This method will return an error until the gRPC service is updated.
Sourcepub async fn rollback_to(&mut self, _name: &str) -> Result<()>
pub async fn rollback_to(&mut self, _name: &str) -> Result<()>
Roll back to a previously created savepoint.
Note: Rollback-to-savepoint is not yet supported via the gRPC service definition. This method will return an error until the gRPC service is updated.