pub struct CdcDiagnosticsConfig {
pub enabled: bool,
pub malformed_snapshot_interval: u64,
pub malformed_hash_retain: u32,
pub malformed_warn_pct: f64,
pub malformed_abort_pct: f64,
pub flush_interval_ms: u32,
pub batch_size: u32,
pub pending_backpressure_watermark: u64,
}Fields
enabled: boolmalformed_snapshot_interval: u64malformed_hash_retain: u32malformed_warn_pct: f64malformed_abort_pct: f64flush_interval_ms: u32batch_size: u32pending_backpressure_watermark: u64Trait Implementations
Sourceimpl Clone for CdcDiagnosticsConfig
impl Clone for CdcDiagnosticsConfig
Sourcefn clone(&self) -> CdcDiagnosticsConfig
fn clone(&self) -> CdcDiagnosticsConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CdcDiagnosticsConfig
impl Debug for CdcDiagnosticsConfig
Sourceimpl Default for CdcDiagnosticsConfig
impl Default for CdcDiagnosticsConfig
Sourceimpl Message for CdcDiagnosticsConfig
impl Message for CdcDiagnosticsConfig
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for CdcDiagnosticsConfig
impl PartialEq for CdcDiagnosticsConfig
impl Copy for CdcDiagnosticsConfig
impl StructuralPartialEq for CdcDiagnosticsConfig