pub struct CdcDiagnosticsResponse {Show 16 fields
pub malformed_change_records: u64,
pub total_change_attempts: u64,
pub malformed_ratio: f64,
pub guardrail_warn_triggered: bool,
pub guardrail_abort_triggered: bool,
pub first_warn_ts_ms: i64,
pub first_abort_ts_ms: i64,
pub guardrail_epoch: u64,
pub uptime_ms: i64,
pub backpressure: bool,
pub config: Option<CdcDiagnosticsConfig>,
pub engine: Option<CdcDiagnosticsEngine>,
pub malformed_snapshots: Vec<CdcMalformedSnapshot>,
pub malformed_hashes: Vec<CdcMalformedHash>,
pub version: String,
pub timestamp_ms: i64,
}Fields
malformed_change_records: u64total_change_attempts: u64malformed_ratio: f64guardrail_warn_triggered: boolguardrail_abort_triggered: boolfirst_warn_ts_ms: i64first_abort_ts_ms: i64guardrail_epoch: u64uptime_ms: i64backpressure: boolconfig: Option<CdcDiagnosticsConfig>engine: Option<CdcDiagnosticsEngine>malformed_snapshots: Vec<CdcMalformedSnapshot>malformed_hashes: Vec<CdcMalformedHash>version: Stringtimestamp_ms: i64Trait Implementations
Sourceimpl Clone for CdcDiagnosticsResponse
impl Clone for CdcDiagnosticsResponse
Sourcefn clone(&self) -> CdcDiagnosticsResponse
fn clone(&self) -> CdcDiagnosticsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CdcDiagnosticsResponse
impl Debug for CdcDiagnosticsResponse
Sourceimpl Default for CdcDiagnosticsResponse
impl Default for CdcDiagnosticsResponse
Sourceimpl Message for CdcDiagnosticsResponse
impl Message for CdcDiagnosticsResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for CdcDiagnosticsResponse
impl PartialEq for CdcDiagnosticsResponse
impl StructuralPartialEq for CdcDiagnosticsResponse