pub struct ProfileOp {Show 21 fields
pub op: String,
pub phase: String,
pub id: u32,
pub op_index: u32,
pub input_rows: u64,
pub rows: u64,
pub time_ns: u64,
pub cpu_time_ns: u64,
pub bytes_out: u64,
pub bytes_alloc: u64,
pub estimate_bytes: u64,
pub estimate_vs_actual: u64,
pub percent_peak: u64,
pub percent_net: u64,
pub cumulative_time_ns: u64,
pub freed_bytes: u64,
pub net_after_op: u64,
pub error_bytes: u64,
pub error_abs_pct: u64,
pub index_name: String,
pub selectivity_est: f64,
}Fields
op: Stringphase: Stringid: u32op_index: u32input_rows: u64rows: u64time_ns: u64cpu_time_ns: u64bytes_out: u64bytes_alloc: u64estimate_bytes: u64estimate_vs_actual: u64percent_peak: u64percent_net: u64cumulative_time_ns: u64freed_bytes: u64net_after_op: u64error_bytes: u64error_abs_pct: u64index_name: Stringselectivity_est: f64Trait Implementations
Sourceimpl Message for ProfileOp
impl Message for ProfileOp
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl StructuralPartialEq for ProfileOp