pub struct ProfilePayload {Show 18 fields
pub profile_version: u32,
pub ops: Vec<ProfileOp>,
pub peak_contributors: Vec<ProfilePeakContributor>,
pub totals: Option<ProfileTotals>,
pub total_time_ns: u64,
pub spills: Option<ProfileSpills>,
pub memory: Option<ProfileMemory>,
pub planner_estimates: Option<ProfilePlannerEstimates>,
pub mem_curve: Vec<ProfileMemCurvePoint>,
pub setop: Option<ProfileSetOp>,
pub hashagg_spills: u64,
pub hashagg_spill_reason: String,
pub committed_txns: u64,
pub graph_store_nodes: u64,
pub graph_store_edges: u64,
pub graph_store_dirty: bool,
pub flagger_findings: Vec<String>,
pub compact: bool,
}Fields
profile_version: u32ops: Vec<ProfileOp>peak_contributors: Vec<ProfilePeakContributor>totals: Option<ProfileTotals>total_time_ns: u64spills: Option<ProfileSpills>memory: Option<ProfileMemory>planner_estimates: Option<ProfilePlannerEstimates>mem_curve: Vec<ProfileMemCurvePoint>setop: Option<ProfileSetOp>hashagg_spills: u64hashagg_spill_reason: Stringcommitted_txns: u64graph_store_nodes: u64graph_store_edges: u64graph_store_dirty: boolflagger_findings: Vec<String>compact: boolTrait Implementations
Sourceimpl Clone for ProfilePayload
impl Clone for ProfilePayload
Sourcefn clone(&self) -> ProfilePayload
fn clone(&self) -> ProfilePayload
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProfilePayload
impl Debug for ProfilePayload
Sourceimpl Default for ProfilePayload
impl Default for ProfilePayload
Sourceimpl Message for ProfilePayload
impl Message for ProfilePayload
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ProfilePayload
impl PartialEq for ProfilePayload
impl StructuralPartialEq for ProfilePayload