pub struct ProfilePlannerEstimates {
pub sum_estimate_bytes: u64,
pub sum_actual_bytes: u64,
pub count_estimated_ops: u32,
pub min_error_abs_pct: f64,
pub max_error_abs_pct: f64,
pub mean_error_abs_pct: f64,
pub median_error_abs_pct: f64,
pub stddev_error_abs_pct: f64,
pub adjusted_estimate_factor: f64,
}Fields
sum_estimate_bytes: u64sum_actual_bytes: u64count_estimated_ops: u32min_error_abs_pct: f64max_error_abs_pct: f64mean_error_abs_pct: f64median_error_abs_pct: f64stddev_error_abs_pct: f64adjusted_estimate_factor: f64Trait Implementations
Sourceimpl Clone for ProfilePlannerEstimates
impl Clone for ProfilePlannerEstimates
Sourcefn clone(&self) -> ProfilePlannerEstimates
fn clone(&self) -> ProfilePlannerEstimates
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProfilePlannerEstimates
impl Debug for ProfilePlannerEstimates
Sourceimpl Default for ProfilePlannerEstimates
impl Default for ProfilePlannerEstimates
Sourceimpl Message for ProfilePlannerEstimates
impl Message for ProfilePlannerEstimates
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ProfilePlannerEstimates
impl PartialEq for ProfilePlannerEstimates
impl Copy for ProfilePlannerEstimates
impl StructuralPartialEq for ProfilePlannerEstimates