Module types

Module types 

Type system for Geode values.

Structs

Range
Range type value
Value
Native representation of Geode values

Enums

ValueKind
Kind of value

Constants

DEFAULT_MAX_JSON_DEPTH
Default maximum JSON nesting depth when decoding values

Functions

decode_value
Decode a JSON value into a typed Value object using the default depth limit.
decode_value_with_max_depth
Decode a JSON value into a typed Value object with a specific depth limit.