Error

Enum Error 

pub enum Error {
Show 13 variants Connection(String), Query { code: String, message: String, }, Auth(String), Io(Error), Json(Error), Quic(String), Tls(String), InvalidDsn(String), Type(String), Timeout, Pool(String), Validation(String), Other(String),
}
Error types that can occur when using the Geode client

Variants



Connection(String)

Connection error



Query

Query execution error

Fields

code: String
message: String


Auth(String)

Authentication error



Io(Error)

I/O error



Json(Error)

JSON serialization/deserialization error



Quic(String)

QUIC connection error



Tls(String)

TLS error



InvalidDsn(String)

Invalid DSN format



Type(String)

Type conversion error



Timeout

Timeout error



Pool(String)

Pool error



Validation(String)

Input validation error



Other(String)

Generic error

Implementations

Source

impl Error

pub fn connection<S: Into<String>>(msg: S) -> Self

Create a connection error

pub fn query<S: Into<String>>(msg: S) -> Self

Create a query error

pub fn protocol<S: Into<String>>(msg: S) -> Self

Create a protocol error

pub fn transaction<S: Into<String>>(msg: S) -> Self

Create a transaction error

pub fn timeout() -> Self

Create a timeout error

pub fn auth<S: Into<String>>(msg: S) -> Self

Create an auth error

pub fn quic<S: Into<String>>(msg: S) -> Self

Create a QUIC error

pub fn tls<S: Into<String>>(msg: S) -> Self

Create a TLS error

pub fn type_error<S: Into<String>>(msg: S) -> Self

Create a type error

pub fn pool<S: Into<String>>(msg: S) -> Self

Create a pool error

pub fn validation<S: Into<String>>(msg: S) -> Self

Create a validation error

pub fn invalid_dsn<S: Into<String>>(msg: S) -> Self

Create an invalid DSN error

pub fn is_retryable(&self) -> bool

Check if the error is retryable

Retryable errors are transient failures that may succeed on retry:

  • Connection errors (network issues)
  • Timeout errors
  • QUIC errors (connection reset, etc.)
  • Query errors with serialization failure codes (40001, 40P01)
pub fn code(&self) -> Option<&str>

Get the error code if this is a query error