pub enum Error {
}Expand description
Error types that can occur when using the Geode client
Variants
Connection(String)
Connection error
Query
Query execution error
Auth(String)
Authentication error
Io(Error)
I/O error
Json(Error)
JSON serialization/deserialization error
Quic(String)
QUIC connection error
Tls(String)
TLS error
InvalidDsn(String)
Invalid DSN format
Type(String)
Type conversion error
Timeout
Timeout error
Pool(String)
Pool error
Validation(String)
Input validation error
Other(String)
Generic error
Implementations
Sourceimpl Error
impl Error
Sourcepub fn connection<S: Into<String>>(msg: S) -> Self
pub fn connection<S: Into<String>>(msg: S) -> Self
Create a connection error
Sourcepub fn transaction<S: Into<String>>(msg: S) -> Self
pub fn transaction<S: Into<String>>(msg: S) -> Self
Create a transaction error
Sourcepub fn type_error<S: Into<String>>(msg: S) -> Self
pub fn type_error<S: Into<String>>(msg: S) -> Self
Create a type error
Sourcepub fn validation<S: Into<String>>(msg: S) -> Self
pub fn validation<S: Into<String>>(msg: S) -> Self
Create a validation error
Sourcepub fn invalid_dsn<S: Into<String>>(msg: S) -> Self
pub fn invalid_dsn<S: Into<String>>(msg: S) -> Self
Create an invalid DSN error
Sourcepub fn is_retryable(&self) -> bool
pub fn is_retryable(&self) -> bool
Check if the error is retryable
Retryable errors are transient failures that may succeed on retry:
- Connection errors (network issues)
- Timeout errors
- QUIC errors (connection reset, etc.)
- Query errors with serialization failure codes (40001, 40P01)