Function as_node
Source pub fn as_node(v: &Value) -> Option<Node>
Convert a driver Value into a typed Node.
Returns None if v is not a node object: it must be an object that
has a labels key and does not have a start_node key (which would
make it an edge).