pub fn as_path(v: &Value) -> Option<Path>
Convert a driver Value into a typed Path.
Value
Path
Returns None if v is not a path object: it must be an object that has both nodes and edges keys. Individual entries that fail to decode as a Node/Edge are skipped.
None
v
nodes
edges
Node
Edge