Protobuf types generated from geode.proto via prost-build/tonic-build.
This module re-exports the generated types and provides helper functions for QUIC transport framing (4-byte big-endian length prefix).
Modules
- client_
packet - Nested message and enum types in
ClientPacket. - execution_
response - Nested message and enum types in
ExecutionResponse. - extended_
value - Nested message and enum types in
ExtendedValue. - geode_
service_ client - Generated client implementations.
- quic_
client_ message - Nested message and enum types in
QuicClientMessage. - quic_
server_ message - Nested message and enum types in
QuicServerMessage. - server_
packet - Nested message and enum types in
ServerPacket. - value
- Nested message and enum types in
Value.
Structs
- Backup
Request - ============================================================================ Backup / Restore
- Backup
Response - Begin
Request - ============================================================================ Transactions
- Begin
Response - Bytes
Value - CdcControl
Request - CdcControl
Response - CdcDiagnostics
Config - CdcDiagnostics
Engine - CdcDiagnostics
Request - ============================================================================ CDC
- CdcDiagnostics
Response - CdcMalformed
Hash - CdcMalformed
Snapshot - Client
Packet - ============================================================================ Transport Wrappers (QUIC framing)
- Column
Definition - Commit
Request - Commit
Response - Data
Page - Decimal
Value - Double
Value - Edge
Value - Error
- Execute
Request - ============================================================================ Query Execution (RUN_GQL + PULL)
- Execution
Metrics - Execution
Response - Explain
Calibration - Explain
Calibration Entry - Explain
Op - Explain
Payload - Explain
Properties - Explain
Totals - Extended
Value - Heartbeat
- Hello
Request - ============================================================================ Authentication (HELLO)
- Hello
Response - IntValue
- List
Value - MapEntry
- MapValue
- Node
Value - Null
Value - Param
- Path
Value - Ping
Request - ============================================================================ Utilities (PING)
- Ping
Response - Profile
MemCurve Point - Profile
Memory - Profile
Op - Profile
Payload - Profile
Peak Contributor - Profile
Planner Estimates - Profile
SetOp - Profile
Spills - Profile
Totals - Pull
Request - Pull
Response - Quic
Client Message - ============================================================================ QUIC Messages
- Quic
Server Message - Restore
Request - Restore
Response - Rollback
Request - Rollback
Response - Rollback
ToRequest - Rollback
ToResponse - Row
- Savepoint
Request - Savepoint
Response - Schema
Definition - Server
Packet - Status
- ============================================================================ Execution Responses
- String
Value - Upload
Backup Request - Upload
Backup Response - Value
Enums
Functions
- decode_
length_ prefix - Decode a 4-byte big-endian length prefix from the start of a byte slice.
- decode_
quic_ server_ message - Decode a QuicServerMessage from raw protobuf bytes (without length prefix).
- encode_
with_ length_ prefix - Encode a QuicClientMessage to protobuf bytes with a 4-byte big-endian length prefix, as required by the QUIC transport.