Type system for Geode values.
Structs
- Edge
- A graph edge (relationship) value.
- Node
- A graph node value.
- Path
- A graph path value (alternating nodes and edges).
- Range
- Range type value
- Value
- Native representation of Geode values
Enums
- Value
Kind - Kind of value
Constants
- DEFAULT_
MAX_ JSON_ DEPTH - Default maximum JSON nesting depth when decoding values
Functions
- decode_
value - Decode a JSON value into a typed Value object using the default depth limit.
- decode_
value_ with_ max_ depth - Decode a JSON value into a typed Value object with a specific depth limit.